URL Example
===========

 `http://127.0.0.1:8000/api/v1/messages.json <http://127.0.0.1:8000/api/v1/messages.json>`_

where:

* http://127.0.0.1:8000  - host name 
* /api - endpoint
* v1 version - number
* messages - resources
* .json - datatype